@@ -7,6 +7,11 @@
 import logging
 
 
+# will format the message to be suitable for the log messaged
+def format_msg(msg):
+    return f' {msg}'
+
+
 class Logger:
     # logger instance
     logger = None
@@ -29,12 +34,12 @@ class Logger:
 
     # log info
     def info(self, msg):
-        self.logger.info(msg)
+        self.logger.info(format_msg(msg))
 
     # log warning
     def warning(self, msg):
-        self.logger.warning(msg)
+        self.logger.warning(format_msg(msg))
 
     # log developer devbug
     def debug(self, msg):
-        self.logger.debug(msg)
+        self.logger.debug(format_msg(msg))
